@@ -67,6 +67,7 @@ local_timezone = tzlocal.get_localzone()
 class GraphBase(ABC):
     """Base class for managing plotting of arbitrary measurement data"""
 
+    @abstractmethod
     def format_measurement(self, measurement):
         """Transform measurement from the queue into something usable by plot()
 
@@ -87,25 +88,10 @@ class GraphBase(ABC):
         """
         pass
 
-    @abstractmethod
-    def update_plot(self, e_graph, e_close, e_stop, q_plot, timer=None):
-        """Animation function to plot data received from queues.
 
-        INPUTS
-        ------
-        - e_graph is set when the graph is activated
-        - e_close is set when the figure has been closed
-        - e_stop is set when there is an external stop request.
-        - q_plot: dict {name: queue} with sensor names and data queues
-        - timer is an optional external timer that gets deactivated here if
-          figure is closed
-        """
-        pass
+class NumericalGraphBase(GraphBase):
 
-
-class NumericalGraph(GraphBase):
-
-    def __init__(self, names, data_types, colors=None, dt_graph=1):
+    def __init__(self, names, data_types, colors=None):
         """Initiate figures and axes for data plot as a function of asked types.
 
         Input
@@ -115,78 +101,21 @@ class NumericalGraph(GraphBase):
                         corresponding data types as values.
         - 'colors': optional dict of colors with keys 'fig', 'ax', and the
                     names of the recordings.
-        - 'dt graph': time interval to update the graph
-                      (only if update_plot is used)
         """
         self.names = names
         self.data_types = data_types
         self.colors = colors
-        self.dt_graph = dt_graph
-
-        self.timezone = local_timezone
 
         self.fig, self.axs = self.create_axes()
 
         self.format_graph()
+        self.set_colors()
+        self.fig.tight_layout()
 
         # Create onclick callback to activate / deactivate autoscaling
         self.cid = self.fig.canvas.mpl_connect('button_press_event',
                                                self.onclick)
 
-    def create_axes(self):
-        """Generate figure/axes as a function of input data types"""
-
-        if len(self.all_data_types) == 3:
-            fig, axes = plt.subplots(1, 3, figsize=(14, 4))
-        elif len(self.all_data_types) == 2:
-            fig, axes = plt.subplots(1, 2, figsize=(10, 4))
-        elif len(self.all_data_types) == 1:
-            fig, ax = plt.subplots(1, 1, figsize=(6, 4))
-            axes = ax,
-        else:
-            msg = f'Mode combination {self.all_data_types} not supported yet'
-            raise Exception(msg)
-
-        axs = {}
-        for ax, datatype in zip(axes, self.all_data_types):
-            ax.set_ylabel(datatype)
-            axs[datatype] = ax
-
-        return fig, axs
-
-    def format_graph(self):
-        """Set colors, time formatting, etc."""
-
-        # Colors -------------------------------------------------------------
-
-        if self.colors is not None:
-
-            self.fig.set_facecolor(self.colors['fig'])
-
-            for ax in self.axs.values():
-                ax.set_facecolor(self.colors['ax'])
-                ax.grid()
-
-        else:
-
-            self.colors = {name: None for name in self.names}
-
-        # Concise formatting of time -----------------------------------------
-
-        self.locator = {}
-        self.formatter = {}
-
-        for ax in self.axs.values():
-            self.locator[ax] = mdates.AutoDateLocator(tz=self.timezone)
-            self.formatter[ax] = mdates.ConciseDateFormatter(self.locator,
-                                                             tz=self.timezone)
-
-        # Finalize figure ----------------------------------------------------
-
-        self.fig.tight_layout()
-
-    # ============================ MISC. methods =============================
-
     @property
     def all_data_types(self):
         """Return a set of all datatypes corresponding to the active names."""
@@ -213,6 +142,141 @@ class NumericalGraph(GraphBase):
         else:
             pass
 
+    def set_colors(self):
+        """"Define fig/ax colors if supplied"""
+        if self.colors is not None:
+            self.fig.set_facecolor(self.colors['fig'])
+
+            for ax in self.axs.values():
+                ax.set_facecolor(self.colors['ax'])
+                ax.grid()
+        else:
+            self.colors = {name: None for name in self.names}
+
+    def create_axes(self):
+        """To be defined in subclasses. Returns fig, axs"""
+        pass
+
+    def format_graph(self):
+        """To be defined in subclasses."""
+        pass
+
+
+class UpdateGraph:
+
+    def __init__(self, graph, q_plot, e_stop,
+                 e_close=None, e_graph=None, dt_graph=1):
+        """Update plot with data received from a queue.
+
+        INPUTS
+        ------
+        - graph: object of GraphBase class and subclasses
+        - q_plot: dict {name: queue} with sensor names and data queues
+        - e_stop is set when there is an external stop request.
+        - e_close (optional) is set when the figure has been closed
+        - e_graph (optional) is set when the graph is activated
+        - 'dt graph': time interval to update the graph
+
+        Attention, if the figure is closed, the e_close event is triggered so
+        do not put in e_close a threading event that is supposed to stay alive
+        even if the figure gets closed. Rather, use the e_stop event.
+        """
+        self.graph = graph
+        self.q_plot = q_plot
+        self.e_stop = e_stop
+        self.e_close = e_close
+        self.e_graph = e_graph
+        self.dt_graph = dt_graph
+
+        self.graph.fig.canvas.mpl_connect('close_event', self.on_fig_close)
+
+    def on_fig_close(self, event):
+        """When figure is closed, set threading events accordingly."""
+        if self.e_close is not None:
+            self.e_close.set()
+        if self.e_graph is not None:
+            self.e_graph.clear()
+
+    def plot_new_data(self, i):
+        """define what to do at each loop of the matplotlib animation."""
+
+        for queue in self.q_plot.values():
+            while queue.qsize() > 0:
+                measurement = queue.get()
+                self.graph.plot(measurement)
+
+        if self.e_stop.is_set():
+            plt.close(self.graph.fig)
+            # since figure is closed, e_close and e_graph are taken care of
+            # by the on_fig_close() function
+
+    def run(self):
+
+        # Below, it does not work if there is no value = before the FuncAnimation
+        ani = FuncAnimation(fig=self.graph.fig,
+                            func=self.plot_new_data,
+                            interval=self.dt_graph * 1000,
+                            cache_frame_data=False)
+
+        plt.show(block=True)  # block=True allow the animation to work even
+        # when matplotlib is in interactive mode (plt.ion()).
+
+        return ani
+
+
+class NumericalGraph(NumericalGraphBase):
+
+    def __init__(self, names, data_types, colors=None):
+        """Initiate figures and axes for data plot as a function of asked types.
+
+        Input
+        -----
+        - names: iterable of names of recordings/sensors that will be plotted.
+        - 'data types': dict with the recording names as keys, and the
+                        corresponding data types as values.
+        - 'colors': optional dict of colors with keys 'fig', 'ax', and the
+                    names of the recordings.
+        """
+        self.timezone = local_timezone
+
+        super().__init__(names=names, data_types=data_types, colors=colors)
+
+    def create_axes(self):
+        """Generate figure/axes as a function of input data types"""
+
+        if len(self.all_data_types) == 4:
+            fig, axes = plt.subplots(2, 2, figsize=(10, 9))
+        if len(self.all_data_types) == 3:
+            fig, axes = plt.subplots(1, 3, figsize=(14, 4))
+        elif len(self.all_data_types) == 2:
+            fig, axes = plt.subplots(1, 2, figsize=(10, 4))
+        elif len(self.all_data_types) == 1:
+            fig, ax = plt.subplots(1, 1, figsize=(6, 4))
+            axes = ax,
+        else:
+            msg = f'Mode combination {self.all_data_types} not supported yet'
+            raise Exception(msg)
+
+        axs = {}
+        for ax, datatype in zip(axes, self.all_data_types):
+            ax.set_ylabel(datatype)
+            axs[datatype] = ax
+
+        return fig, axs
+
+    def format_graph(self):
+        """Set colors, time formatting, etc."""
+
+        # Concise formatting of time -----------------------------------------
+
+        self.locator = {}
+        self.formatter = {}
+
+        for ax in self.axs.values():
+            self.locator[ax] = mdates.AutoDateLocator(tz=self.timezone)
+            self.formatter[ax] = mdates.ConciseDateFormatter(self.locator,
+                                                             tz=self.timezone)
+
     # ============================= Main methods =============================
 
     @staticmethod
@@ -290,59 +354,6 @@ class NumericalGraph(GraphBase):
             ax.xaxis.set_major_locator(self.locator[ax])
             ax.xaxis.set_major_formatter(self.formatter[ax])
 
-    def update_plot(self, e_graph, e_close, e_stop, q_plot, timer=None):
-        """Threaded function to plot data from data received in a queue.
-
-        INPUTS
-        ------
-        - e_graph is set when the graph is activated
-        - e_close is set when the figure has been closed
-        - e_stop is set when there is an external stop request.
-        - q_plot: dict {name: queue} with sensor names and data queues
-        - timer is an optional external timer that gets deactivated here if
-        figure is closed
-
-        Attention, if the figure is closed, the e_close event is triggered by
-        update_plot, so do not put in e_stop a threading event that is supposed
-        to stay alive even if the figure gets closed. Rather, use the e_stop
-        event.
-
-        Note: any request to update_plot when a graph is already active is ignored
-        because update_plot is blocking (due to the plt.show() after FuncAnimation).
-        """
-        def on_fig_close(event):
-            """When figure is closed, set threading events accordingly."""
-            e_close.set()
-            e_graph.clear()
-            if timer is not None:
-                timer.stop()
-
-        # Connect a figure close event to the close() function above
-        self.fig.canvas.mpl_connect('close_event', on_fig_close)
-
-        def plot_new_data(i):
-            """define what to do at each loop of the matplotlib animation."""
-
-            for queue in q_plot.values():
-                while queue.qsize() > 0:
-                    measurement = queue.get()
-                    self.plot(measurement)
-
-            if e_stop.is_set():
-                plt.close(self.fig)
-                # since figure is closed, e_close and e_graph are taken care of
-                # by the on_fig_close() function
-
-        # Below, it does not work if there is no value = before the FuncAnimation
-        ani = FuncAnimation(self.fig, plot_new_data,
-                            interval=self.dt_graph * 1000,
-                            cache_frame_data=False)
-
-        plt.show(block=True)  # block=True allow the animation to work even
-        # when matplotlib is in interactive mode (plt.ion()).
-
-        return ani
-
 
 # ============== Classes using Graph-like objects to plot data ===============
 
@@ -394,14 +405,16 @@ class PlotUpdatedData:
     (e.g. from live sensors, or from reading a file, etc.)
     """
 
-    def __init__(self, graph, dt_data=1):
+    def __init__(self, graph, dt_data=1, dt_graph=1):
         """Parameters:
 
         - graph: object of GraphBase class and subclasses
         - dt_data is how often (in s) the loop checks for (or gets) new data.
+        - dt_graph is how often (in s) the graph animation is updated
         """
         self.graph = graph
         self.timer = oclock.Timer(interval=dt_data, name='Data Update')
+        self.dt_graph = dt_graph
 
         self.queues = {name: Queue() for name in self.names}
         self.e_graph = Event()
@@ -423,27 +436,33 @@ class PlotUpdatedData:
 
         self.e_graph.set()  # This is supposed to be set when graph is active.
 
-        # update_plot is inherited later from the Graph-like classes
-        self.graph.update_plot(e_graph=self.e_graph, e_close=self.e_stop,
-                               e_stop=self.e_stop, q_plot=self.queues,
-                               timer=self.timer)
         # e_stop two times, because we want a figure closure event to also
         # trigger stopping of the recording process here.
 
+        update_graph = UpdateGraph(self.graph,
+                                   q_plot=self.queues,
+                                   e_stop=self.e_stop,
+                                   e_close=self.e_stop,
+                                   e_graph=self.e_graph,
+                                   dt_graph=self.dt_graph)
+        update_graph.run()
+
 
 class PlotLiveSensors(PlotUpdatedData):
     """Create live graph by reading the sensors directly."""
 
-    def __init__(self, graph, recordings, dt_data=1):
+    def __init__(self, graph, recordings, dt_data=1, dt_graph=1):
         """Parameters:
 
         - graph: object of GraphBase class and subclasses
         - recordings: dict {name: recording(RecordingBase) object}
-        - dt_data: how often (in s) sensors are probed"""
+        - dt_data: how often (in s) sensors are probed
+        - dt_graph is how often (in s) the graph animation is updated
+        """
         self.recordings = recordings
         self.names = list(recordings)
 
-        super().__init__(graph=graph, dt_data=dt_data)
+        super().__init__(graph=graph, dt_data=dt_data, dt_graph=dt_graph)
 
     def get_data(self, name):
         """Check if new data is read by sensor, and put it in data queue."""
@@ -468,7 +487,7 @@ class PlotSavedDataUpdated(PlotUpdatedData, PlotSavedData):
     """Extends PlotSavedData to be able to periodically read file to update."""
 
     def __init__(self, names, graph, SavedData, file_names,
-                 path='.', dt_data=1):
+                 path='.', dt_data=1, dt_graph=1):
         """Parameters:
 
         - names: names of sensors/recordings to consider
@@ -480,6 +499,7 @@ class PlotSavedDataUpdated(PlotUpdatedData, PlotSavedData):
         - file_names: dict {name: filename (str)} of files containing data
         - path: directory in which data is saved
         - dt_data: how often (in s) the files are checked for updates.
+        - dt_graph: how often (in s) the graph animation is updated.
         """
         PlotSavedData.__init__(self,
                                names=names,
@@ -490,7 +510,8 @@ class PlotSavedDataUpdated(PlotUpdatedData, PlotSavedData):
 
         PlotUpdatedData.__init__(self,
                                  graph=graph,
-                                 dt_data=dt_data)
+                                 dt_data=dt_data,
+                                 dt_graph=dt_graph)
 
     def get_data(self, name):
         """Check if new data is added to file, and put it in data queue."""
